@@ -30,8 +30,6 @@ class DataFrameSummary(object):
         self.columns_stats = self._get_stats()
         self.corr = df.corr()
         self.plot = plot
-        self.continuous=[]
-        self.categorical=[]
 
     def __getitem__(self, column):
         if isinstance(column, str) and self._clean_column(column):
@@ -62,6 +60,8 @@ class DataFrameSummary(object):
         raise KeyError(column)
 
     def _get_pairplot(self,data):
+        continuous=[]
+        categorical=[]
         for i in data.columns:
              if (data[i].nunique()/data.shape[0])*100 > 20 : ##unique nos in a column are more than 20% then it is a continuous variable
                 continuous.append(i)
